package com.zehong.gassdevicereport.netty;

import com.zehong.gassdevicereport.netty.handler.FactoryDetectorUdpServerHandler;
import com.zehong.gassdevicereport.netty.handler.UDPServerHandler;
import com.zehong.gassdevicereport.netty.property.UdpStartProperty;
import io.netty.channel.SimpleChannelInboundHandler;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;
import javax.annotation.PostConstruct;
import java.util.HashMap;
import java.util.Map;

/**
 * @author geng
 * upd服务启动类
 */
@Component
public class UdpServerStart implements ApplicationContextAware {

    private Logger logger = LoggerFactory.getLogger(UdpServerStart.class);

    private ApplicationContext applicationContext;

    private Map<Integer,Class> handlerMap = new HashMap<Integer,Class>(){{
        put(65011,UDPServerHandler.class);
        //工业报警器
        put(65012,FactoryDetectorUdpServerHandler.class);
    }};

    @Value("${UDPNetty.ports}")
    private int[] ports;

    @PostConstruct
    public void udpStart(){
        UdpStartProperty property = new UdpStartProperty();
        for(int port : ports){
            try {
                property.setPort(port);
                SimpleChannelInboundHandler handler = (SimpleChannelInboundHandler)applicationContext.getBean(handlerMap.get(port));
                property.setHandler(handler);
                UdpStartProperty udpServer = (UdpStartProperty) property.clone();
                udpServer.start();
            } catch (CloneNotSupportedException e) {
                logger.error("udp 原型创建失败！");
            }
        }
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

}
