package com.zehong.gassdevicereport.netty.decryptreported.flowmeter;

import com.zehong.gassdevicereport.entity.TDeviceReportData;
import com.zehong.gassdevicereport.utils.HexUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author zehong
 * 接收苍南EVC300体积修正仪、天信CPU卡式体积修正仪上报数据
 */
public class FlowmeterDecryptReportedData implements DecryptReportedData{

    private Logger logger = LoggerFactory.getLogger(FlowmeterDecryptReportedData.class);

    private String reportedDataStr;

    private String deviceType;

    public FlowmeterDecryptReportedData(String reportedDataStr,String deviceType) {
        this.reportedDataStr = reportedDataStr;
        this.deviceType = deviceType;
    }

    @Override
    public TDeviceReportData getReportedData(){
        try {
            TDeviceReportData tDeviceReportData = new TDeviceReportData();
            //设备编号
            tDeviceReportData.setDeviceNum(getDeviceNum());
            //设备上报时间
            Date reportedTime = getReportedTime();
            tDeviceReportData.setReportTime(reportedTime);
            // 标况累计量
            double standardConditionAccumulation = HexUtils.hexToDouble(reportedDataStr.substring(48, 64));
            tDeviceReportData.setStandardConditionAccumulation(new BigDecimal(standardConditionAccumulation));
            // 工况累计量
            double workingConditionAccumulation = HexUtils.hexToDouble(reportedDataStr.substring(64, 80));
            if("苍南EVC300体积修正仪".equals(deviceType)){
                tDeviceReportData.setWorkingConditionAccumulation(new BigDecimal(workingConditionAccumulation));
            }else{
                tDeviceReportData.setResidualQuantity(new BigDecimal(workingConditionAccumulation));
            }

            // 标况流量
            float standardConditionFlow = HexUtils.hexToFloat(reportedDataStr.substring(80, 88));
            tDeviceReportData.setStandardConditionFlow(new BigDecimal(standardConditionFlow));
            // 工况流量
            float workingConditionFlow = HexUtils.hexToFloat(reportedDataStr.substring(88, 96));
            tDeviceReportData.setWorkingConditionFlow(new BigDecimal(workingConditionFlow));
            // 温度
            float temperature = HexUtils.hexToFloat(reportedDataStr.substring(96, 104));
            tDeviceReportData.setTemperature(new BigDecimal(temperature));
            // 压力
            float pressure = HexUtils.hexToFloat(reportedDataStr.substring(104, 112));
            tDeviceReportData.setPressure(new BigDecimal(pressure));
            //通讯字段
            String communicationStatus = getCommunicationStatus();
            tDeviceReportData.setCommunicationStatus(communicationStatus);
            //设备状态
            String deviceStatus = getDeviceStatus();
            tDeviceReportData.setDeviceStatus(deviceStatus);
            return tDeviceReportData;
        } catch (Exception e) {
            logger.error("上报数据组装数据报错！"+e);
        }
        return null;
    }

    /**
     * 获取设备编号
     * @return String
     */
    private String getDeviceNum(){
        String deviceNum = reportedDataStr.substring(0,36);
        StringBuilder deviceNumStr = new StringBuilder("");
        for(int i = 0; i < deviceNum.length(); i+=2){
            String code = deviceNum.substring(i,i+2);
            byte codeByte = HexUtils.hexToByte(code);
            deviceNumStr.append(codeByte);
        }
        return deviceNumStr.toString();
    }

    /**
     * 获取上报时间
     * @return Date
     * @throws ParseException
     */
    private Date getReportedTime() throws ParseException {
        String reportTime = reportedDataStr.substring(36,48);
        if("00".equals(reportTime.substring(0,2))){
            return new Date();
        }
        StringBuilder timeStr = new StringBuilder("");
        timeStr.append(reportTime.substring(0,2));
        timeStr.append("-");
        timeStr.append(reportTime.substring(2,4));
        timeStr.append("-");
        timeStr.append(reportTime.substring(4,6));
        timeStr.append(" ");
        timeStr.append(reportTime.substring(6,8));
        timeStr.append(":");
        timeStr.append(reportTime.substring(8,10));
        timeStr.append(":");
        timeStr.append(reportTime.substring(10,12));
        return new SimpleDateFormat("yy-MM-dd HH:mm:ss").parse(timeStr.toString());
    }

    /**
     * 通讯字
     * @return String
     */
    private String getCommunicationStatus(){
        String communicationStatus = reportedDataStr.substring(112, 116);
        StringBuilder communicationStatusStr = new StringBuilder("");
        communicationStatusStr.append( HexUtils.hexToByte(communicationStatus.substring(0,2)));
        communicationStatusStr.append( HexUtils.hexToByte(communicationStatus.substring(2,4)));
        return communicationStatusStr.toString();
    }

    /**
     * 设备状态字段 16进制转为二进制  高位或地位不足8位时左边补0
     * @return String
     */
    private String getDeviceStatus(){
        String deviceStatus = reportedDataStr.substring(116, 120);
        String lowPosition = HexUtils.hexToBinary(deviceStatus.substring(0,2));
        String heightPosition = HexUtils.hexToBinary(deviceStatus.substring(2,4));
        return deviceType+lowPosition+heightPosition;
    }

}
