package com.zehong.gassdevicereport.netty.decryptreported.flowmeter;

import com.zehong.gassdevicereport.entity.TDeviceReportData;
import com.zehong.gassdevicereport.utils.HexUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author zehong
 * 接收天津市第五机床厂C型体积积算仪(天五C型)上报数据
 */
public class Tian5cFlowmeterDecryptReportedData implements DecryptReportedData{

    private Logger logger = LoggerFactory.getLogger(Tian5cFlowmeterDecryptReportedData.class);

    private String reportedDataStr;

    private String deviceType;

    public Tian5cFlowmeterDecryptReportedData(String reportedDataStr, String deviceType) {
        this.reportedDataStr = reportedDataStr;
        this.deviceType = deviceType;
    }

    @Override
    public TDeviceReportData getReportedData(){
        try {
            TDeviceReportData tDeviceReportData = new TDeviceReportData();
            //设备编号
            tDeviceReportData.setDeviceNum(getDeviceNum());
            //设备上报时间
            Date reportedTime = getReportedTime();
            tDeviceReportData.setReportTime(reportedTime);
            // 标况累计流量
            double standardConditionAccumulation = HexUtils.hexToFloat(reportedDataStr.substring(48, 56));
            tDeviceReportData.setStandardConditionAccumulation(new BigDecimal(standardConditionAccumulation));
            // 标况瞬时流量
            float standardConditionFlow = HexUtils.hexToFloat(reportedDataStr.substring(56, 64));
            tDeviceReportData.setStandardConditionFlow(new BigDecimal(standardConditionFlow));
            // 压力
            float pressure = HexUtils.hexToFloat(reportedDataStr.substring(64, 72));
            tDeviceReportData.setPressure(new BigDecimal(pressure));
            // 温度
            float temperature = HexUtils.hexToFloat(reportedDataStr.substring(80, 88));
            tDeviceReportData.setTemperature(new BigDecimal(temperature));

            //通讯字段
            String communicationStatus = getCommunicationStatus();
            tDeviceReportData.setCommunicationStatus(communicationStatus);
            tDeviceReportData.setDeviceStatus(deviceType);
            return tDeviceReportData;
        } catch (Exception e) {
            logger.error("上报数据组装数据报错！"+e);
        }
        return null;
    }

    /**
     * 获取设备编号
     * @return
     */
    private String getDeviceNum(){
        String deviceNum = reportedDataStr.substring(0,36);
        StringBuilder deviceNumStr = new StringBuilder("");
        for(int i = 0; i < deviceNum.length(); i+=2){
            String code = deviceNum.substring(i,i+2);
            byte codeByte = HexUtils.hexToByte(code);
            deviceNumStr.append(codeByte);
        }
        return deviceNumStr.toString();
    }

    /**
     * 获取上报时间
     * @return
     * @throws ParseException
     */
    private Date getReportedTime() throws ParseException {
        String reportTime = reportedDataStr.substring(36,48);
        if("00".equals(reportTime.substring(0,2))){
            return new Date();
        }
        StringBuilder timeStr = new StringBuilder("");
        timeStr.append(reportTime.substring(0,2));
        timeStr.append("-");
        timeStr.append(reportTime.substring(2,4));
        timeStr.append("-");
        timeStr.append(reportTime.substring(4,6));
        timeStr.append(" ");
        timeStr.append(reportTime.substring(6,8));
        timeStr.append(":");
        timeStr.append(reportTime.substring(8,10));
        timeStr.append(":");
        timeStr.append(reportTime.substring(10,12));
        return new SimpleDateFormat("yy-MM-dd HH:mm:ss").parse(timeStr.toString());
    }

    /**
     * 通讯字
     * @return
     */
    private String getCommunicationStatus(){
        String communicationStatus = reportedDataStr.substring(96, 100);
        StringBuilder communicationStatusStr = new StringBuilder("");
        communicationStatusStr.append( HexUtils.hexToByte(communicationStatus.substring(0,2)));
        communicationStatusStr.append( HexUtils.hexToByte(communicationStatus.substring(2,4)));
        return communicationStatusStr.toString();
    }

}
