package com.zehong.gassdevicereport.netty.handler;

import com.alibaba.fastjson.JSONObject;
import com.zehong.gassdevicereport.entity.TDeviceAlarm;
import com.zehong.gassdevicereport.entity.TRelationDeviceData;
import com.zehong.gassdevicereport.entity.TRelationDeviceInfo;
import com.zehong.gassdevicereport.service.ITDeviceAlarmService;
import com.zehong.gassdevicereport.service.ITRelationDeviceDataService;
import com.zehong.gassdevicereport.service.ITRelationDeviceInfoService;
import com.zehong.gassdevicereport.utils.DateUtils;
import com.zehong.gassdevicereport.utils.HttpUtil;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandler.Sharable;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.channel.socket.DatagramPacket;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author geng
 * 工业报警器数据解析类
 */
@Component
@Sharable
public class FactoryDetectorUdpServerHandler extends SimpleChannelInboundHandler<DatagramPacket> {

    private Logger logger = LoggerFactory.getLogger(FactoryDetectorUdpServerHandler.class);

    @Autowired
    private ITRelationDeviceDataService itRelationDeviceDataService;

    @Value("${webSocektUrl}")
    private String webSocektUrl;

    @Autowired
    private ITDeviceAlarmService itDeviceAlarmService;

    @Autowired
    private ITRelationDeviceInfoService itRelationDeviceInfoService;

    @Override
    protected void channelRead0(ChannelHandlerContext ctx, DatagramPacket msg)throws Exception{
       //获取上传参数
        ByteBuf buf = msg.content();
        String msgStr = convertByteBufToString(buf);
        logger.info("FactoryDetectorUdp 入参：" + msgStr);
        //解析上传参数 参数实例：{"number":"866384067166661","status":1,"nd":"0","time":1680768201}
        //String[] msgInfo = msgStr.split("/");
        Map<String,Object> msgInfo = JSONObject.parseObject(msgStr,Map.class);
        //保存上报数据
        saveDeviceData(msgInfo);
        //根据设备状态报警
        judgeDeviceStatus(msgInfo);
    }


    /**
     * 保存上报数据
     * @param msgInfo 信息
     */
    private void saveDeviceData(Map<String,Object> msgInfo) {
        //设备上报数据入库
        TRelationDeviceData tRelationDeviceData = new TRelationDeviceData();
        tRelationDeviceData.setDeviceCode((String)msgInfo.get("number"));
        tRelationDeviceData.setStatus(String.valueOf(msgInfo.get("status")));
        tRelationDeviceData.setPotency(new BigDecimal((String)msgInfo.get("nd")));
        itRelationDeviceDataService.insertTRelationDeviceData(tRelationDeviceData);
    }

    /**
     * 根据设备状态更新报警信息
     * @param msgInfo 设备上报信息
     */
    private void judgeDeviceStatus(Map<String,Object> msgInfo) {
        List<TRelationDeviceInfo> relationDeviceInfos = itRelationDeviceInfoService.getDeviceInfoByDeviceCode((String)msgInfo.get("number"));
        if(null != relationDeviceInfos && relationDeviceInfos.size()>0){
            TDeviceAlarm alarm = itDeviceAlarmService.selectTDeviceAlarmByDeviceId(relationDeviceInfos.get(0).getDeviceId());
            if(0 != (int) msgInfo.get("status") && 1 != (int)msgInfo.get("status")){
                if(null != alarm){
                    alarm.setCreateTime(DateUtils.getNowDate());
                    alarm.setAlarmType(String.valueOf(msgInfo.get("status")));
                    alarm.setAlarmValue(String.valueOf(msgInfo.get("nd")));
                    itDeviceAlarmService.updateTDeviceAlarm(alarm);
                    return;
                }
                TDeviceAlarm tDeviceAlarm = new TDeviceAlarm();
                tDeviceAlarm.setDeviceId(relationDeviceInfos.get(0).getDeviceId());
                tDeviceAlarm.setAlarmType(String.valueOf(msgInfo.get("status")));
                tDeviceAlarm.setDeviceType(relationDeviceInfos.get(0).getDeviceType());
                tDeviceAlarm.setStartTime(new Date());
                tDeviceAlarm.setAlarmValue(String.valueOf(msgInfo.get("nd")));
                itDeviceAlarmService.insertTDeviceAlarm(tDeviceAlarm);
                pushWedSocket(tDeviceAlarm.getAlarmId());
            }else {
                if(null != alarm){
                    //手动消警的报警结束更新状态
                    if("4".equals(alarm.getDealStatus())){
                        alarm.setDealStatus("");
                    }
                    alarm.setEndTime(DateUtils.getNowDate());
                    itDeviceAlarmService.updateTDeviceAlarm(alarm);
                    pushWedSocket(alarm.getAlarmId());
                }
            }
        }
    }

    /**
     * 推送报警信息
     * @param alarmId 报警id
     */
    private void pushWedSocket(Long alarmId){
        //推送信息至websocket
        StringBuilder url = new StringBuilder(webSocektUrl)
                .append("?")
                .append("alarmId=")
                .append(alarmId);
        try {
            HttpUtil.doGet(url.toString());
        } catch (IOException e) {
            logger.error("websocket推送失败："+e);
        }
    }

    /**
     * buf转字符串
     * @param buf
     * @return
     */
    private String convertByteBufToString(ByteBuf buf) {
        String str;
        if(buf.hasArray()) {
            // 处理堆缓冲区
            str = new String(buf.array(), buf.arrayOffset() + buf.readerIndex(), buf.readableBytes());
        } else { // 处理直接缓冲区以及复合缓冲区
            byte[] bytes = new byte[buf.readableBytes()];
            buf.getBytes(buf.readerIndex(), bytes);
            str = new String(bytes, 0, buf.readableBytes());
        }
        return str;
    }

    private String deviceStatus(String code){
        switch (code){
            case "0":
                return "预热";
            case "1":
                return "正常";
            case "2":
                return "错误";
            case "3":
                return "传感器故障";
            case "4":
                return "报警";
            case "5":
                return "低报";
            case "6":
                return "高报";
            case "7":
                return "通信故障";
            case "8":
                return "通信故障";
            case "9":
                return "离线";
            case "10":
                return "电量低";
            case "11":
                return "主电故障";
            case "12":
                return "备电故障";
            case "13":
                return "无此节点";
            case "14":
                return "低电压";
            case "15":
                return "故障";
            case "16":
                return "报警联动";
            case "17":
                return "低低报";
            case "18":
                return "高高报";
            case "19":
                return "水位淹没报警";
            default:
                return "";

        }

    }
}
