package com.zehong.gassdevicereport.netty.handler;

import com.zehong.gassdevicereport.constant.Constant;
import com.zehong.gassdevicereport.entity.ReciveReportData;
import com.zehong.gassdevicereport.entity.TDeviceReportData;
import com.zehong.gassdevicereport.netty.decryptreported.PressureDecryptReportedData;
import com.zehong.gassdevicereport.service.ITDeviceReportDataService;
import com.zehong.gassdevicereport.utils.CrcUtil;
import com.zehong.gassdevicereport.utils.HexUtils;
import com.zehong.gassdevicereport.utils.RedisUtil;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandler.Sharable;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.channel.socket.DatagramPacket;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
@Sharable
public class UDPServerHandler extends SimpleChannelInboundHandler<DatagramPacket> {

    private Logger logger = LoggerFactory.getLogger(UDPServerHandler.class);

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private ITDeviceReportDataService itDeviceReportDataService;

    private final static String METER = "4";

    private final static String METER_ALARM = "1";

    @Override
    protected void channelRead0(ChannelHandlerContext ctx, DatagramPacket msg) throws Exception {
        //msg为接收到的客户端传递的数据   个人这边直接传的json 数据
        ByteBuf buf = msg.content();
        byte [] bytes1 = new byte[buf.readableBytes()];
        //复制内容到字节数组bytes
        buf.readBytes(bytes1);
        String msgStr = HexUtils.bytesToHex(bytes1);
        logger.info("receiveUPDMsgstr======="+msgStr);
        byte[] bytes = HexUtils.hexToByteArray( msgStr.substring(0,msgStr.length()-4));
        String checkVule = CrcUtil.getCrcToHex(bytes,true);
        String checkCode = msgStr.substring(msgStr.length()-4,msgStr.length());
        if(!checkVule.equals(checkCode)){
            logger.error("接收数据校验失败");
            throw new Exception("接收数据校验失败");
        }

        TDeviceReportData tDeviceReportData = new PressureDecryptReportedData(msgStr).getReportedData();
        //缓存设备信息
        ReciveReportData reciveReportData = new ReciveReportData();
        reciveReportData.setDeviceCode(tDeviceReportData.getDeviceNum());
        reciveReportData.setDeviceType(METER);
        reciveReportData.setAlarmType(METER_ALARM);
        reciveReportData.setPressure(tDeviceReportData.getPressure());
        redisUtil.set(Constant.DEVICE_REDIS_KEY + reciveReportData.getDeviceCode(),reciveReportData);
        //设备上报数据入库
        itDeviceReportDataService.insertTDeviceReportData(tDeviceReportData);
    }
}
