package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.SysDictDataDao;
import com.zehong.gassdevicereport.dao.SysDictTypeDao;
import com.zehong.gassdevicereport.entity.SysDictData;
import com.zehong.gassdevicereport.entity.SysDictType;
import com.zehong.gassdevicereport.service.ISysDictTypeService;
import com.zehong.gassdevicereport.utils.RedisUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 字典 业务层处理
 * 
 * @author zehong
 */
@Service
public class SysDictTypeServiceImpl implements ISysDictTypeService
{
    @Resource
    private SysDictTypeDao sysDictTypeDao;

    @Resource
    private SysDictDataDao sysDictDataDao;

    @Resource
    private RedisUtil redisUtil;

    /**
     * 根据条件分页查询字典类型
     * 
     * @param dictType 字典类型信息
     * @return 字典类型集合信息
     */
    @Override
    public List<SysDictType> selectDictTypeList(SysDictType dictType)
    {
        return sysDictTypeDao.selectDictTypeList(dictType);
    }

    /**
     * 根据所有字典类型
     * 
     * @return 字典类型集合信息
     */
    @Override
    public List<SysDictType> selectDictTypeAll()
    {
        return sysDictTypeDao.selectDictTypeAll();
    }

    /**
     * 根据字典类型查询字典数据
     * 
     * @param dictType 字典类型
     * @return 字典数据集合信息
     */
    @Override
    public List<SysDictData> selectDictDataByType(String dictType)
    {
        List<SysDictData> dictDatas = (List<SysDictData>) redisUtil.get("dictDatas" + dictType);
        if(null != dictDatas && !dictDatas.isEmpty()){
            return dictDatas;
        }
        dictDatas = sysDictDataDao.selectDictDataByType(dictType);
        if(null != dictDatas && !dictDatas.isEmpty()){
            redisUtil.set("dictDatas" + dictType,dictDatas,1000 * 3600 * 6);
        }

        return dictDatas;
    }

    /**
     * 根据字典类型ID查询信息
     * 
     * @param dictId 字典类型ID
     * @return 字典类型
     */
    @Override
    public SysDictType selectDictTypeById(Long dictId)
    {
        return sysDictTypeDao.selectDictTypeById(dictId);
    }

    /**
     * 根据字典类型查询信息
     * 
     * @param dictType 字典类型
     * @return 字典类型
     */
    @Override
    public SysDictType selectDictTypeByType(String dictType)
    {
        return sysDictTypeDao.selectDictTypeByType(dictType);
    }

    /**
     * 批量删除字典类型信息
     * 
     * @param dictIds 需要删除的字典ID
     * @return 结果
     */
    @Override
    public void deleteDictTypeByIds(Long[] dictIds)
    {
        for (Long dictId : dictIds)
        {
            sysDictTypeDao.deleteDictTypeById(dictId);
        }
    }
}
