package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.TDeviceAlarmDao;
import com.zehong.gassdevicereport.entity.TDeviceAlarm;
import com.zehong.gassdevicereport.service.ITDeviceAlarmService;
import com.zehong.gassdevicereport.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 报警信息Service业务层处理
 * 
 * @author zehong
 * @date 2021-08-03
 */
@Service
public class TDeviceAlarmServiceImpl implements ITDeviceAlarmService 
{
    @Resource
    private TDeviceAlarmDao tDeviceAlarmDao;

    /**
     * 查询报警信息
     * 
     * @param alarmId 报警信息ID
     * @return 报警信息
     */
    @Override
    public TDeviceAlarm selectTDeviceAlarmById(Long alarmId)
    {
        return tDeviceAlarmDao.selectTDeviceAlarmById(alarmId);
    }

    /**
     * 查询报警信息列表
     * 
     * @param tDeviceAlarm 报警信息
     * @return 报警信息
     */
    @Override
    public List<TDeviceAlarm> selectTDeviceAlarmList(TDeviceAlarm tDeviceAlarm)
    {
        return tDeviceAlarmDao.selectTDeviceAlarmList(tDeviceAlarm);
    }

    /**
     * 新增报警信息
     * 
     * @param tDeviceAlarm 报警信息
     * @return 结果
     */
    @Override
    public int insertTDeviceAlarm(TDeviceAlarm tDeviceAlarm)
    {
        tDeviceAlarm.setCreateTime(new Date());
        return tDeviceAlarmDao.insertTDeviceAlarm(tDeviceAlarm);
    }

    /**
     * 修改报警信息
     * 
     * @param tDeviceAlarm 报警信息
     * @return 结果
     */
    @Override
    public int updateTDeviceAlarm(TDeviceAlarm tDeviceAlarm)
    {
        tDeviceAlarm.setUpdateTime(DateUtils.getNowDate());
        return tDeviceAlarmDao.updateTDeviceAlarm(tDeviceAlarm);
    }

    /**
     * 批量删除报警信息
     * 
     * @param alarmIds 需要删除的报警信息ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceAlarmByIds(Long[] alarmIds)
    {
        return tDeviceAlarmDao.deleteTDeviceAlarmByIds(alarmIds);
    }

    /**
     * 删除报警信息信息
     * 
     * @param alarmId 报警信息ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceAlarmById(Long alarmId)
    {
        return tDeviceAlarmDao.deleteTDeviceAlarmById(alarmId);
    }

    /**
     * 根据设备id查询报警信息
     * @param deviceId
     * @return
     */
    @Override
    public TDeviceAlarm selectTDeviceAlarmByDeviceId(Long deviceId){
        return tDeviceAlarmDao.selectTDeviceAlarmByDeviceId(deviceId);
    }
}
