package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.TDeviceReportDataDao;
import com.zehong.gassdevicereport.entity.TDeviceReportData;
import com.zehong.gassdevicereport.service.ITDeviceReportDataService;
import com.zehong.gassdevicereport.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 设备监控Service业务层处理
 * 
 * @author zehong
 * @date 2021-08-09
 */
@Service
public class TDeviceReportDataServiceImpl implements ITDeviceReportDataService {

    @Resource
    private TDeviceReportDataDao tDeviceReportDataDao;

    /**
     * 查询设备监控
     * 
     * @param deviceReportDataId 设备监控ID
     * @return 设备监控
     */
    @Override
    public TDeviceReportData selectTDeviceReportDataById(Long deviceReportDataId)
    {
        return tDeviceReportDataDao.selectTDeviceReportDataById(deviceReportDataId);
    }

    /**
     * 查询设备监控列表
     * 
     * @param tDeviceReportData 设备监控
     * @return 设备监控
     */
    @Override
    public List<TDeviceReportData> selectTDeviceReportDataList(TDeviceReportData tDeviceReportData)
    {
        return tDeviceReportDataDao.selectTDeviceReportDataList(tDeviceReportData);
    }

    /**
     * 新增设备监控
     * 
     * @param tDeviceReportData 设备监控
     * @return 结果
     */
    @Override
    public int insertTDeviceReportData(TDeviceReportData tDeviceReportData)
    {
        tDeviceReportData.setCreateTime(DateUtils.getNowDate());
        return tDeviceReportDataDao.insertTDeviceReportData(tDeviceReportData);
    }

    /**
     * 修改设备监控
     * 
     * @param tDeviceReportData 设备监控
     * @return 结果
     */
    @Override
    public int updateTDeviceReportData(TDeviceReportData tDeviceReportData)
    {
        tDeviceReportData.setUpdateTime(DateUtils.getNowDate());
        return tDeviceReportDataDao.updateTDeviceReportData(tDeviceReportData);
    }

    /**
     * 批量删除设备监控
     * 
     * @param deviceReportDataIds 需要删除的设备监控ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceReportDataByIds(Long[] deviceReportDataIds)
    {
        return tDeviceReportDataDao.deleteTDeviceReportDataByIds(deviceReportDataIds);
    }

    /**
     * 删除设备监控信息
     * 
     * @param deviceReportDataId 设备监控ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceReportDataById(Long deviceReportDataId)
    {
        return tDeviceReportDataDao.deleteTDeviceReportDataById(deviceReportDataId);
    }
}
