package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.TMonitorDeviceDao;
import com.zehong.gassdevicereport.entity.TMonitorDevice;
import com.zehong.gassdevicereport.service.ITMonitorDeviceService;
import com.zehong.gassdevicereport.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 设备监控Service业务层处理
 * 
 * @author zehong
 * @date 2021-08-03
 */
@Service
public class TMonitorDeviceServiceImpl implements ITMonitorDeviceService
{
    @Resource
    private TMonitorDeviceDao tMonitorDeviceDao;

    /**
     * 查询设备监控
     * 
     * @param monitorId 设备监控ID
     * @return 设备监控
     */
    @Override
    public TMonitorDevice selectTMonitorDeviceById(Long monitorId)
    {
        return tMonitorDeviceDao.selectTMonitorDeviceById(monitorId);
    }

    /**
     * 查询设备监控列表
     * 
     * @param tMonitorDevice 设备监控
     * @return 设备监控
     */
    @Override
    public List<TMonitorDevice> selectTMonitorDeviceList(TMonitorDevice tMonitorDevice)
    {
        return tMonitorDeviceDao.selectTMonitorDeviceList(tMonitorDevice);
    }

    /**
     * 新增设备监控
     * 
     * @param tMonitorDevice 设备监控
     * @return 结果
     */
    @Override
    public int insertTMonitorDevice(TMonitorDevice tMonitorDevice)
    {
        tMonitorDevice.setCreateTime(DateUtils.getNowDate());
        return tMonitorDeviceDao.insertTMonitorDevice(tMonitorDevice);
    }

    /**
     * 修改设备监控
     * 
     * @param tMonitorDevice 设备监控
     * @return 结果
     */
    @Override
    public int updateTMonitorDevice(TMonitorDevice tMonitorDevice)
    {
        tMonitorDevice.setUpdateTime(DateUtils.getNowDate());
        return tMonitorDeviceDao.updateTMonitorDevice(tMonitorDevice);
    }

    /**
     * 批量删除设备监控
     * 
     * @param monitorIds 需要删除的设备监控ID
     * @return 结果
     */
    @Override
    public int deleteTMonitorDeviceByIds(Long[] monitorIds)
    {
        return tMonitorDeviceDao.deleteTMonitorDeviceByIds(monitorIds);
    }

    /**
     * 删除设备监控信息
     * 
     * @param monitorId 设备监控ID
     * @return 结果
     */
    @Override
    public int deleteTMonitorDeviceById(Long monitorId)
    {
        return tMonitorDeviceDao.deleteTMonitorDeviceById(monitorId);
    }

    @Override
    public List<TMonitorDevice> getDeviceInfosByIotNo(String iotNo){
        return tMonitorDeviceDao.getDeviceInfosByIotNo(iotNo);
    }
}
