package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.TRelationDeviceDataDao;
import com.zehong.gassdevicereport.entity.TRelationDeviceData;
import com.zehong.gassdevicereport.service.ITRelationDeviceDataService;
import com.zehong.gassdevicereport.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 关联设备数据Service业务层处理
 * 
 * @author zehong
 * @date 2023-03-27
 */
@Service
public class TRelationDeviceDataServiceImpl implements ITRelationDeviceDataService {

    @Resource
    private TRelationDeviceDataDao tRelationDeviceDataDao;

    /**
     * 查询关联设备数据
     * 
     * @param dataId 关联设备数据ID
     * @return 关联设备数据
     */
    @Override
    public TRelationDeviceData selectTRelationDeviceDataById(Long dataId) {
        return tRelationDeviceDataDao.selectTRelationDeviceDataById(dataId);
    }

    /**
     * 查询关联设备数据列表
     * 
     * @param tRelationDeviceData 关联设备数据
     * @return 关联设备数据
     */
    @Override
    public List<TRelationDeviceData> selectTRelationDeviceDataList(TRelationDeviceData tRelationDeviceData) {
        return tRelationDeviceDataDao.selectTRelationDeviceDataList(tRelationDeviceData);
    }


    /**
     * 新增关联设备数据
     * 
     * @param tRelationDeviceData 关联设备数据
     * @return 结果
     */
    @Override
    public int insertTRelationDeviceData(TRelationDeviceData tRelationDeviceData) {
        tRelationDeviceData.setCreateTime(DateUtils.getNowDate());
        return tRelationDeviceDataDao.insertTRelationDeviceData(tRelationDeviceData);
    }

    /**
     * 修改关联设备数据
     * 
     * @param tRelationDeviceData 关联设备数据
     * @return 结果
     */
    @Override
    public int updateTRelationDeviceData(TRelationDeviceData tRelationDeviceData) {
        tRelationDeviceData.setUpdateTime(DateUtils.getNowDate());
        return tRelationDeviceDataDao.updateTRelationDeviceData(tRelationDeviceData);
    }

    /**
     * 批量删除关联设备数据
     * 
     * @param dataIds 需要删除的关联设备数据ID
     * @return 结果
     */
    @Override
    public int deleteTRelationDeviceDataByIds(Long[] dataIds) {
        return tRelationDeviceDataDao.deleteTRelationDeviceDataByIds(dataIds);
    }

    /**
     * 删除关联设备数据信息
     * 
     * @param dataId 关联设备数据ID
     * @return 结果
     */
    @Override
    public int deleteTRelationDeviceDataById(Long dataId) {
        return tRelationDeviceDataDao.deleteTRelationDeviceDataById(dataId);
    }
}
