package com.zehong.gassdevicereport.service.impl;

import com.zehong.gassdevicereport.dao.TRelationDeviceInfoDao;
import com.zehong.gassdevicereport.entity.TRelationDeviceInfo;
import com.zehong.gassdevicereport.service.ITRelationDeviceInfoService;
import com.zehong.gassdevicereport.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;

/**
 * 关联设备Service业务层处理
 * 
 * @author zehong
 * @date 2023-03-27
 */
@Service
public class TRelationDeviceInfoServiceImpl implements ITRelationDeviceInfoService {
    @Autowired
    private TRelationDeviceInfoDao tRelationDeviceInfoDao;

    /**
     * 查询关联设备
     * 
     * @param relationId 关联设备ID
     * @return 关联设备
     */
    @Override
    public TRelationDeviceInfo selectTRelationDeviceInfoById(Long relationId) {
        return tRelationDeviceInfoDao.selectTRelationDeviceInfoById(relationId);
    }

    /**
     * 查询关联设备列表
     * 
     * @param tRelationDeviceInfo 关联设备
     * @return 关联设备
     */
    @Override
    public List<TRelationDeviceInfo> selectTRelationDeviceInfoList(TRelationDeviceInfo tRelationDeviceInfo) {
        return tRelationDeviceInfoDao.selectTRelationDeviceInfoList(tRelationDeviceInfo);
    }

    /**
     * 新增关联设备
     * 
     * @param tRelationDeviceInfo 关联设备
     * @return 结果
     */
    @Override
    public int insertTRelationDeviceInfo(TRelationDeviceInfo tRelationDeviceInfo) {
        tRelationDeviceInfo.setCreateTime(DateUtils.getNowDate());
        return tRelationDeviceInfoDao.insertTRelationDeviceInfo(tRelationDeviceInfo);
    }

    /**
     * 修改关联设备
     * 
     * @param tRelationDeviceInfo 关联设备
     * @return 结果
     */
    @Override
    public int updateTRelationDeviceInfo(TRelationDeviceInfo tRelationDeviceInfo) {
        tRelationDeviceInfo.setUpdateTime(DateUtils.getNowDate());
        return tRelationDeviceInfoDao.updateTRelationDeviceInfo(tRelationDeviceInfo);
    }

    /**
     * 批量删除关联设备
     * 
     * @param relationIds 需要删除的关联设备ID
     * @return 结果
     */
    @Override
    public int deleteTRelationDeviceInfoByIds(Long[] relationIds) {
        return tRelationDeviceInfoDao.deleteTRelationDeviceInfoByIds(relationIds);
    }

    /**
     * 删除关联设备信息
     * 
     * @param relationId 关联设备ID
     * @return 结果
     */
    @Override
    public int deleteTRelationDeviceInfoById(Long relationId) {
        return tRelationDeviceInfoDao.deleteTRelationDeviceInfoById(relationId);
    }

    @Override
    public List<TRelationDeviceInfo> getDeviceInfoByDeviceCode(String deviceCode){
        return tRelationDeviceInfoDao.getDeviceInfoByDeviceCode(deviceCode);
    }
}
