package com.zehong.gassdevicereport.task.impl;

import com.zehong.gassdevicereport.constant.Constant;
import com.zehong.gassdevicereport.entity.ReciveReportData;
import com.zehong.gassdevicereport.entity.TDeviceAlarm;
import com.zehong.gassdevicereport.entity.TMonitorDevice;
import com.zehong.gassdevicereport.service.ITDeviceAlarmService;
import com.zehong.gassdevicereport.service.ITMonitorDeviceService;
import com.zehong.gassdevicereport.task.ScheduledOfTask;
import com.zehong.gassdevicereport.utils.DateUtils;
import com.zehong.gassdevicereport.utils.HttpUtil;
import com.zehong.gassdevicereport.utils.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 处理接收数据并发送报警信息
 */
@Component
@Slf4j
public class DealWithAndSendRecevieDataTask implements ScheduledOfTask {

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private ITMonitorDeviceService itMonitorDeviceService;

    @Autowired
    private ITDeviceAlarmService itDeviceAlarmService;

    @Value("${webSocektUrl}")
    private String webSocektUrl;

    private final static String PIPE = "O";
    private final static String PIPE_ALARMTYPE = "0";

    @Override
    public void execute() {
        //获取设备监控信息
        List<TMonitorDevice> monitorDevices = itMonitorDeviceService.selectTMonitorDeviceList(new TMonitorDevice());
        for(TMonitorDevice monitorDevice : monitorDevices){
            ReciveReportData deviceInfo = (ReciveReportData) redisUtil.get(Constant.DEVICE_REDIS_KEY+monitorDevice.getIotNo());
            if(null == deviceInfo){
                return;
            }
            //查询设备在报警表中信息
            insertAlarmInfo(monitorDevice.getDeviceId(),monitorDevice.getDeviceThreshold(), deviceInfo);
            //获取关联设备阈值
            if(StringUtils.isNotBlank(monitorDevice.getRelationIotNo())){
                ReciveReportData relationDeviceInfo = (ReciveReportData) redisUtil.get(Constant.DEVICE_REDIS_KEY+monitorDevice.getRelationIotNo());
                if(null == relationDeviceInfo){
                    return;
                }
                //关联设备
                insertAlarmInfo(monitorDevice.getRelationDeviceId(),monitorDevice.getRelationDeviceThreshold(), relationDeviceInfo);
                //关联管道
                ReciveReportData pipe = new ReciveReportData();
                pipe.setPressure(deviceInfo.getPressure().subtract(relationDeviceInfo.getPressure()));
                pipe.setDeviceType(PIPE);
                pipe.setAlarmType(PIPE_ALARMTYPE);
                insertAlarmInfo(monitorDevice.getRelationPipeId(),monitorDevice.getRelationPipeThreshold(),pipe);
            }
        }


    }

    /**
     *插入报警信息
     * @param deviceId  设备编号
     * @param deviceThreshold  设备浓度
     * @param deviceInfo  设备上报信息
     */
    private void insertAlarmInfo(Long deviceId,BigDecimal deviceThreshold, ReciveReportData deviceInfo) {
        TDeviceAlarm alarm = itDeviceAlarmService.selectTDeviceAlarmByDeviceId(deviceId);
        //比较设备上报信息及阈值信息
        if(deviceThreshold.compareTo(deviceInfo.getPressure()) == -1){
            //判断报警表中是否有该设备报警信息：无新增报警信息、有更新报警信息
            if(null != alarm){
                //TODO  添加更新字段
                alarm.setCreateTime(DateUtils.getNowDate());
                itDeviceAlarmService.updateTDeviceAlarm(alarm);
            }else{
                TDeviceAlarm alarmInsert = new TDeviceAlarm();
                alarmInsert.setDeviceId(deviceId);
                alarmInsert.setAlarmType(deviceInfo.getAlarmType());
                alarmInsert.setDeviceType(deviceInfo.getDeviceType());
                alarmInsert.setStartTime(new Date());
                alarmInsert.setAlarmValue(deviceInfo.getPressure().toString());
                itDeviceAlarmService.insertTDeviceAlarm(alarmInsert);
                pushWedSocket(alarmInsert.getAlarmId());

            }
        }else {
            if(null != alarm){
                if(null == alarm.getEndTime()){
                    //手动消警的报警结束更新状态
                    if("4".equals(alarm.getDealStatus())){
                        alarm.setDealStatus("");
                    }
                    alarm.setEndTime(DateUtils.getNowDate());
                    itDeviceAlarmService.updateTDeviceAlarm(alarm);
                    pushWedSocket(alarm.getAlarmId());
                }
            }
        }
    }

    /**
     * 推送报警信息
     * @param alarmId 报警id
     */
    private void pushWedSocket(Long alarmId){
        //推送信息至websocket
        StringBuilder url = new StringBuilder(webSocektUrl)
                .append("?")
                .append("alarmId=")
                .append(alarmId);
        try {
            HttpUtil.doGet(url.toString());
        } catch (IOException e) {
            log.error("websocket推送失败："+e);
        }
    }
}

